#!/bin/bash
#
# source: ftp://ftp.x.org/pub/individual/driver/xf86-video-intel-2.9.1.tar.bz2
#
# maintainer: gmg (g.monpontet@gmail.com)
#

soft='xf86-video-intel'
softversion='2.9.1'
packageversion='64.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest

cd $src
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
   --prefix=/usr \
   --mandir=/usr/man

make -j2
make install DESTDIR=$dest

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

gzip -9 $dest/usr/man/man?/*

# Documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS COPYING NEWS README $dest/usr/doc/$soft-$softversion


# Description file
mkdir -p $dest/install
cat << "EODESC" > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

                |-----handy-ruler---------------------------------------------------|
xf86-video-intel: xf86-video-intel
xf86-video-intel:
xf86-video-intel: xf86-video-intel is part of X11.
xf86-video-intel:
xf86-video-intel: For more information about the X.Org Foundation (the providers of
xf86-video-intel: the X.Org implementation of the X Window System).
xf86-video-intel:
xf86-video-intel: http://www.x.org
xf86-video-intel:
xf86-video-intel:
xf86-video-intel:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5
